@@ -161,7 +161,12 @@ sub setup_aws_security {
       if ($security_group eq $sg) {
          return "$security_group already set for this host",'';
       }
-      Net::FullAuto::FA_Core::handle_error($error) if $error;
+      my $n=$main::aws->{fullauto}->
+            {SecurityGroups}->[0]->{GroupName}||'';
+      $c='aws ec2 describe-security-groups '.
+            "--group-names $n";
+      ($hash,$output,$error)=run_aws_cmd($c);
+      return '',$error if $error;
       my $cidr=$hash->{SecurityGroups}->[0]->{IpPermissions}
               ->[0]->{IpRanges}->[0]->{CidrIp};
       $c='aws ec2 create-security-group --group-name '.
